@@ -1,7 +1,7 @@
-from django.conf import settings
 from rest_framework import serializers
 from rest_framework.exceptions import PermissionDenied
 
+from django_burl.conf import settings
 from django_burl.models import BriefURL
 
 
