@@ -1,9 +1,9 @@
 import secrets
 
-from django.conf import settings
-
 from hashids import Hashids
 
+from django_burl.conf import settings
+
 
 def make_burl(ceiling=1000):
     """
